#pragma once
#include <SDL.h>
#include <SDL_opengl.h>
#include "physics.h"

// Recommended for compatibility bullshit.
#if SDL_BYTEORDER == SDL_BIG_ENDIAN
#  define RMASK 0xff000000
#  define GMASK 0x00ff0000
#  define BMASK 0x0000ff00
#  define AMASK 0x000000ff
#else
#  define RMASK 0x000000ff
#  define GMASK 0x0000ff00
#  define BMASK 0x00ff0000
#  define AMASK 0xff000000
#endif
#define RGBMASK RMASK,GMASK,BMASK,AMASK

#define WINDOW_CAPTION "Lephisto"

// Info about opengl screen.
typedef struct {
  int w, h;         // Window dimensions.
  int depth;        // Depth in bpp.
  int fullscreen;   // 1 = fullscreen, 0 = windowed.
  int r, g, b, a;   // Framebuffer values in bits.
  int doublebuf;    // Double buffer.
} gl_info;

extern gl_info gl_screen; // Local structure set with gl_init etc.

// Spritesheet info.
typedef struct {
  FP w, h;        // Real size of the image (excluding POT buffer.
  FP rw, rh;      // Size of POT surface.
  FP sx, sy;      // Number of sprites on x and y axes.
  FP sw, sh;      // Size of each sprite.
  GLuint texture; // The opengl texture itself.
} gl_texture;

// gl_texute loading/freeing.
gl_texture* gl_loadImage(SDL_Surface* surface); // Frees the surface.
gl_texture* gl_newImage(const char* path);
gl_texture* gl_newSprite(const char* path, const int sx, const int sy);
void gl_free(gl_texture* texture);

// Rendering.
void gl_blitSprite(gl_texture* sprite, Vec2* pos, const int sx, const int sy);
void gl_blitStatic(gl_texture* texture, Vec2* pos);
void gl_bindCamera(Vec2* pos);

// Initialize/cleanup.
int gl_init(void);
void gl_exit(void);

